=== modified file 'bzrlib/dirstate.py'
--- bzrlib/dirstate.py	2011-04-19 13:59:07 +0000
+++ bzrlib/dirstate.py	2011-04-21 20:32:16 +0000
@@ -2474,7 +2474,7 @@
             # the suffix is from tree_index+1:parent_count+1.
             new_location_suffix = [DirState.NULL_PARENT_DETAILS] * (parent_count - tree_index)
             # now stitch in all the entries from this tree
-            for path, entry in tree.inventory.iter_entries_by_dir():
+            for path, entry in tree.iter_entries_by_dir():
                 # here we process each trees details for each item in the tree.
                 # we first update any existing entries for the id at other paths,
                 # then we either create or update the entry for the id at the

=== modified file 'bzrlib/plugins/weave_fmt/__init__.py'
--- bzrlib/plugins/weave_fmt/__init__.py	2011-03-13 00:08:28 +0000
+++ bzrlib/plugins/weave_fmt/__init__.py	2011-05-04 22:23:20 +0000
@@ -82,7 +82,7 @@
     'bzrlib.plugins.weave_fmt.repository.RepositoryFormat7',
     'Transitional format in 0.8.  Slower than knit.',
     branch_format='bzrlib.branch.BzrBranchFormat5',
-    tree_format='bzrlib.workingtree.WorkingTreeFormat3',
+    tree_format='bzrlib.workingtree_3.WorkingTreeFormat3',
     hidden=True,
     deprecated=True)
 

=== modified file 'bzrlib/plugins/weave_fmt/bzrdir.py'
--- bzrlib/plugins/weave_fmt/bzrdir.py	2011-03-23 13:26:59 +0000
+++ bzrlib/plugins/weave_fmt/bzrdir.py	2011-05-04 22:23:20 +0000
@@ -599,7 +599,7 @@
                 if name in bzrcontents:
                     self.bzrdir.transport.delete(name)
         else:
-            from bzrlib.workingtree import WorkingTreeFormat3
+            from bzrlib.workingtree_3 import WorkingTreeFormat3
             self.step('Upgrading working tree')
             self.bzrdir.transport.mkdir('checkout', mode=self.dir_mode)
             self.make_lock('checkout')

=== modified file 'bzrlib/tests/__init__.py'
--- bzrlib/tests/__init__.py	2011-04-18 00:44:08 +0000
+++ bzrlib/tests/__init__.py	2011-04-21 01:19:32 +0000
@@ -2125,18 +2125,20 @@
                       % (process_args, retcode, process.returncode))
         return [out, err]
 
-    def check_inventory_shape(self, inv, shape):
-        """Compare an inventory to a list of expected names.
+    def check_tree_shape(self, tree, shape):
+        """Compare a tree to a list of expected names.
 
         Fail if they are not precisely equal.
         """
         extras = []
         shape = list(shape)             # copy
-        for path, ie in inv.entries():
+        for path, ie in tree.iter_entries_by_dir():
             name = path.replace('\\', '/')
             if ie.kind == 'directory':
                 name = name + '/'
-            if name in shape:
+            if name == "/":
+                pass # ignore root entry
+            elif name in shape:
                 shape.remove(name)
             else:
                 extras.append(name)

=== modified file 'bzrlib/tests/blackbox/test_exceptions.py'
--- bzrlib/tests/blackbox/test_exceptions.py	2011-05-03 22:59:49 +0000
+++ bzrlib/tests/blackbox/test_exceptions.py	2011-05-04 19:55:26 +0000
@@ -55,7 +55,7 @@
         if os.name != "posix":
             raise tests.TestNotApplicable("Needs system beholden to C locales")
         out, err = self.run_bzr_subprocess(["\xa0"],
-            env_changes={"LANG": "C"},
+            env_changes={"LANG": "C", "LC_ALL": "C"},
             universal_newlines=True,
             retcode=errors.EXIT_ERROR)
         self.assertContainsRe(err, r"^bzr: ERROR: .*'\\xa0'.* unsupported")

=== modified file 'bzrlib/tests/per_repository/__init__.py'
--- bzrlib/tests/per_repository/__init__.py	2011-03-09 01:33:12 +0000
+++ bzrlib/tests/per_repository/__init__.py	2011-05-02 22:39:15 +0000
@@ -110,7 +110,6 @@
     prefix = 'bzrlib.tests.per_repository.'
     test_repository_modules = [
         'test_add_fallback_repository',
-        'test_add_inventory_by_delta',
         'test_break_lock',
         'test_check',
         'test_commit_builder',

=== modified file 'bzrlib/tests/per_repository/test_add_fallback_repository.py'
--- bzrlib/tests/per_repository/test_add_fallback_repository.py	2009-08-13 05:17:12 +0000
+++ bzrlib/tests/per_repository/test_add_fallback_repository.py	2011-05-02 22:39:15 +0000
@@ -17,9 +17,7 @@
 """Tests for Repository.add_fallback_repository."""
 
 from bzrlib import (
-    bzrdir,
     errors,
-    remote,
     )
 from bzrlib.revision import NULL_REVISION
 from bzrlib.tests import TestNotApplicable

=== modified file 'bzrlib/tests/per_repository/test_fetch.py'
--- bzrlib/tests/per_repository/test_fetch.py	2011-04-02 20:53:50 +0000
+++ bzrlib/tests/per_repository/test_fetch.py	2011-05-02 22:44:40 +0000
@@ -20,7 +20,6 @@
     bzrdir,
     errors,
     gpg,
-    graph,
     remote,
     repository,
     tests,
@@ -356,29 +355,3 @@
         self.addCleanup(source.unlock)
         target.fetch(source, revision_id='B-id')
 
-
-class TestSource(TestCaseWithRepository):
-    """Tests for/about the results of Repository._get_source."""
-
-    def test_no_absent_records_in_stream_with_ghosts(self):
-        # XXX: Arguably should be in per_interrepository but
-        # doesn't actually gain coverage there; need a specific set of
-        # permutations to cover it.
-        # bug lp:376255 was reported about this.
-        builder = self.make_branch_builder('repo')
-        builder.start_series()
-        builder.build_snapshot('tip', ['ghost'],
-            [('add', ('', 'ROOT_ID', 'directory', ''))],
-            allow_leftmost_as_ghost=True)
-        builder.finish_series()
-        b = builder.get_branch()
-        b.lock_read()
-        self.addCleanup(b.unlock)
-        repo = b.repository
-        source = repo._get_source(repo._format)
-        search = graph.PendingAncestryResult(['tip'], repo)
-        stream = source.get_stream(search)
-        for substream_type, substream in stream:
-            for record in substream:
-                self.assertNotEqual('absent', record.storage_kind,
-                    "Absent record for %s" % (((substream_type,) + record.key),))

=== modified file 'bzrlib/tests/per_repository/test_repository.py'
--- bzrlib/tests/per_repository/test_repository.py	2011-04-16 10:11:51 +0000
+++ bzrlib/tests/per_repository/test_repository.py	2011-05-04 19:06:44 +0000
@@ -210,8 +210,8 @@
         rev_tree = tree.branch.repository.revision_tree(second_revision)
         rev_tree.lock_read()
         self.addCleanup(rev_tree.unlock)
-        inv = rev_tree.inventory
-        rich_root = (inv.root.revision != second_revision)
+        root_revision = rev_tree.get_file_revision(rev_tree.get_root_id())
+        rich_root = (root_revision != second_revision)
         self.assertEqual(rich_root,
                          tree.branch.repository.supports_rich_root())
 
@@ -545,7 +545,8 @@
         rev_tree = tree.branch.repository.revision_tree(tree.last_revision())
         rev_tree.lock_read()
         self.addCleanup(rev_tree.unlock)
-        self.assertEqual('rev_id', rev_tree.inventory.root.revision)
+        root_id = rev_tree.get_root_id()
+        self.assertEqual('rev_id', rev_tree.get_file_revision(root_id))
 
     def test_pointless_commit(self):
         tree = self.make_branch_and_tree('.')
@@ -635,8 +636,8 @@
             # expected_record_names.
             # Note that the file keys can be in any order, so this test is
             # written to allow that.
-            inv = repo.get_inventory('rev_id')
-            root_item_key = ('file', inv.root.file_id, ['rev_id'])
+            rev_tree = repo.revision_tree('rev_id')
+            root_item_key = ('file', rev_tree.get_root_id(), ['rev_id'])
             self.assertTrue(root_item_key in item_keys)
             item_keys.remove(root_item_key)
 
@@ -758,27 +759,6 @@
         self.assertEquals(inv_sha1, repo.get_revision('A').inventory_sha1)
         repo.unlock()
 
-    def test_install_revisions(self):
-        wt = self.make_branch_and_tree('source')
-        wt.commit('A', allow_pointless=True, rev_id='A')
-        repo = wt.branch.repository
-        repo.lock_write()
-        repo.start_write_group()
-        repo.sign_revision('A', gpg.LoopbackGPGStrategy(None))
-        repo.commit_write_group()
-        repo.unlock()
-        repo.lock_read()
-        self.addCleanup(repo.unlock)
-        repo2 = self.make_repository('repo2')
-        revision = repo.get_revision('A')
-        tree = repo.revision_tree('A')
-        signature = repo.get_signature_text('A')
-        repo2.lock_write()
-        self.addCleanup(repo2.unlock)
-        repository.install_revisions(repo2, [(revision, tree, signature)])
-        self.assertEqual(revision, repo2.get_revision('A'))
-        self.assertEqual(signature, repo2.get_signature_text('A'))
-
     # XXX: this helper duplicated from tests.test_repository
     def make_remote_repository(self, path, shared=False):
         """Make a RemoteRepository object backed by a real repository that will

=== modified file 'bzrlib/tests/per_repository_vf/__init__.py'
--- bzrlib/tests/per_repository_vf/__init__.py	2011-04-19 12:48:51 +0000
+++ bzrlib/tests/per_repository_vf/__init__.py	2011-05-02 22:44:40 +0000
@@ -37,8 +37,10 @@
 
 def load_tests(basic_tests, module, loader):
     testmod_names = [
+        'test_add_inventory_by_delta',
         'test_check',
         'test_check_reconcile',
+        'test_fetch',
         'test_reconcile',
         'test_repository',
         ]

=== renamed file 'bzrlib/tests/per_repository/test_add_inventory_by_delta.py' => 'bzrlib/tests/per_repository_vf/test_add_inventory_by_delta.py'
--- bzrlib/tests/per_repository/test_add_inventory_by_delta.py	2009-06-18 18:18:36 +0000
+++ bzrlib/tests/per_repository_vf/test_add_inventory_by_delta.py	2011-05-02 22:39:15 +0000
@@ -17,11 +17,19 @@
 """Tests for Repository.add_inventory_by_delta."""
 
 from bzrlib import errors, revision
-from bzrlib.tests.per_repository import TestCaseWithRepository
+from bzrlib.tests.per_repository_vf import (
+    all_repository_vf_format_scenarios,
+    TestCaseWithRepository
+    )
+from bzrlib.tests.scenarios import load_tests_apply_scenarios
+
+load_tests = load_tests_apply_scenarios
 
 
 class TestAddInventoryByDelta(TestCaseWithRepository):
 
+    scenarios = all_repository_vf_format_scenarios()
+
     def _get_repo_in_write_group(self, path='repository'):
         repo = self.make_repository(path)
         repo.lock_write()

=== added file 'bzrlib/tests/per_repository_vf/test_fetch.py'
--- bzrlib/tests/per_repository_vf/test_fetch.py	1970-01-01 00:00:00 +0000
+++ bzrlib/tests/per_repository_vf/test_fetch.py	2011-05-02 22:44:40 +0000
@@ -0,0 +1,57 @@
+# Copyright (C) 2007-2011 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+
+"""Tests for fetch between repositories of the same type."""
+
+from bzrlib import (
+    graph,
+    )
+from bzrlib.tests.per_repository_vf import (
+    TestCaseWithRepository,
+    all_repository_vf_format_scenarios,
+    )
+from bzrlib.tests.scenarios import load_tests_apply_scenarios
+
+load_tests = load_tests_apply_scenarios
+
+
+class TestSource(TestCaseWithRepository):
+    """Tests for/about the results of Repository._get_source."""
+
+    scenarios = all_repository_vf_format_scenarios()
+
+    def test_no_absent_records_in_stream_with_ghosts(self):
+        # XXX: Arguably should be in per_interrepository but
+        # doesn't actually gain coverage there; need a specific set of
+        # permutations to cover it.
+        # bug lp:376255 was reported about this.
+        builder = self.make_branch_builder('repo')
+        builder.start_series()
+        builder.build_snapshot('tip', ['ghost'],
+            [('add', ('', 'ROOT_ID', 'directory', ''))],
+            allow_leftmost_as_ghost=True)
+        builder.finish_series()
+        b = builder.get_branch()
+        b.lock_read()
+        self.addCleanup(b.unlock)
+        repo = b.repository
+        source = repo._get_source(repo._format)
+        search = graph.PendingAncestryResult(['tip'], repo)
+        stream = source.get_stream(search)
+        for substream_type, substream in stream:
+            for record in substream:
+                self.assertNotEqual('absent', record.storage_kind,
+                    "Absent record for %s" % (((substream_type,) + record.key),))

=== modified file 'bzrlib/tests/per_repository_vf/test_repository.py'
--- bzrlib/tests/per_repository_vf/test_repository.py	2011-03-14 00:09:25 +0000
+++ bzrlib/tests/per_repository_vf/test_repository.py	2011-05-02 22:39:15 +0000
@@ -18,6 +18,8 @@
 
 from bzrlib import (
     errors,
+    gpg,
+    repository as _mod_repository,
     tests,
     versionedfile,
     )
@@ -112,6 +114,27 @@
         self.assertRaises(errors.ObjectNotLocked,
             inventories.add_lines, ('foo',), [], [])
 
+    def test_install_revisions(self):
+        wt = self.make_branch_and_tree('source')
+        wt.commit('A', allow_pointless=True, rev_id='A')
+        repo = wt.branch.repository
+        repo.lock_write()
+        repo.start_write_group()
+        repo.sign_revision('A', gpg.LoopbackGPGStrategy(None))
+        repo.commit_write_group()
+        repo.unlock()
+        repo.lock_read()
+        self.addCleanup(repo.unlock)
+        repo2 = self.make_repository('repo2')
+        revision = repo.get_revision('A')
+        tree = repo.revision_tree('A')
+        signature = repo.get_signature_text('A')
+        repo2.lock_write()
+        self.addCleanup(repo2.unlock)
+        _mod_repository.install_revisions(repo2, [(revision, tree, signature)])
+        self.assertEqual(revision, repo2.get_revision('A'))
+        self.assertEqual(signature, repo2.get_signature_text('A'))
+
 
 class TestCaseWithComplexRepository(TestCaseWithRepository):
 

=== modified file 'bzrlib/tests/per_tree/test_inv.py'
--- bzrlib/tests/per_tree/test_inv.py	2011-04-09 21:00:33 +0000
+++ bzrlib/tests/per_tree/test_inv.py	2011-04-20 14:58:20 +0000
@@ -25,6 +25,7 @@
     )
 from bzrlib.mutabletree import MutableTree
 from bzrlib.tests import TestSkipped
+from bzrlib.tree import InventoryTree
 from bzrlib.transform import _PreviewTree
 from bzrlib.uncommit import uncommit
 
@@ -136,32 +137,49 @@
 
     def test_canonical_path(self):
         work_tree = self._make_canonical_test_tree()
+        if not isinstance(work_tree, InventoryTree):
+            raise tests.TestNotApplicable(
+                "test not applicable on non-inventory tests")
         self.assertEqual('dir/file',
                          work_tree.get_canonical_inventory_path('Dir/File'))
 
     def test_canonical_path_before_commit(self):
         work_tree = self._make_canonical_test_tree(False)
-        # note: not committed.
+        if not isinstance(work_tree, InventoryTree):
+            raise tests.TestNotApplicable(
+                "test not applicable on non-inventory tests")        # note: not committed.
         self.assertEqual('dir/file',
                          work_tree.get_canonical_inventory_path('Dir/File'))
 
     def test_canonical_path_dir(self):
         # check it works when asked for just the directory portion.
         work_tree = self._make_canonical_test_tree()
+        if not isinstance(work_tree, InventoryTree):
+            raise tests.TestNotApplicable(
+                "test not applicable on non-inventory tests")
         self.assertEqual('dir', work_tree.get_canonical_inventory_path('Dir'))
 
     def test_canonical_path_root(self):
         work_tree = self._make_canonical_test_tree()
+        if not isinstance(work_tree, InventoryTree):
+            raise tests.TestNotApplicable(
+                "test not applicable on non-inventory tests")
         self.assertEqual('', work_tree.get_canonical_inventory_path(''))
         self.assertEqual('/', work_tree.get_canonical_inventory_path('/'))
 
     def test_canonical_path_invalid_all(self):
         work_tree = self._make_canonical_test_tree()
+        if not isinstance(work_tree, InventoryTree):
+            raise tests.TestNotApplicable(
+                "test not applicable on non-inventory tests")
         self.assertEqual('foo/bar',
                          work_tree.get_canonical_inventory_path('foo/bar'))
 
     def test_canonical_invalid_child(self):
         work_tree = self._make_canonical_test_tree()
+        if not isinstance(work_tree, InventoryTree):
+            raise tests.TestNotApplicable(
+                "test not applicable on non-inventory tests")
         self.assertEqual('dir/None',
                          work_tree.get_canonical_inventory_path('Dir/None'))
 
@@ -176,6 +194,9 @@
         work_tree.add(['test/', 'test/file', 'Test'])
 
         test_tree = self._convert_tree(work_tree)
+        if not isinstance(test_tree, InventoryTree):
+            raise tests.TestNotApplicable(
+                "test not applicable on non-inventory tests")
         test_tree.lock_read()
         self.addCleanup(test_tree.unlock)
 

=== modified file 'bzrlib/tests/per_workingtree/test_add.py'
--- bzrlib/tests/per_workingtree/test_add.py	2010-11-02 22:12:19 +0000
+++ bzrlib/tests/per_workingtree/test_add.py	2011-05-04 20:44:14 +0000
@@ -16,12 +16,9 @@
 
 """Tests for interface conformance of 'WorkingTree.add'"""
 
-import os
-
 from bzrlib import (
     errors,
     inventory,
-    osutils,
     tests,
     )
 from bzrlib.tests.per_workingtree import TestCaseWithWorkingTree

=== modified file 'bzrlib/tests/per_workingtree/test_add_reference.py'
--- bzrlib/tests/per_workingtree/test_add_reference.py	2011-01-12 18:11:10 +0000
+++ bzrlib/tests/per_workingtree/test_add_reference.py	2011-05-04 20:44:14 +0000
@@ -53,8 +53,7 @@
         tree.lock_write()
         try:
             self.assertEqual(tree.path2id('sub-tree'), 'sub-tree-root-id')
-            self.assertEqual(tree.inventory['sub-tree-root-id'].kind,
-                             'tree-reference')
+            self.assertEqual(tree.kind('sub-tree-root-id'), 'tree-reference')
             tree.commit('commit reference')
             basis = tree.basis_tree()
             basis.lock_read()

=== modified file 'bzrlib/tests/per_workingtree/test_annotate_iter.py'
--- bzrlib/tests/per_workingtree/test_annotate_iter.py	2009-07-10 07:14:02 +0000
+++ bzrlib/tests/per_workingtree/test_annotate_iter.py	2011-05-04 20:44:14 +0000
@@ -16,14 +16,6 @@
 
 """Tests for interface conformance of 'WorkingTree.annotate_iter'"""
 
-import os
-
-from bzrlib import (
-    errors,
-    inventory,
-    osutils,
-    tests,
-    )
 from bzrlib.tests.per_workingtree import TestCaseWithWorkingTree
 
 

=== modified file 'bzrlib/tests/per_workingtree/test_basis_inventory.py'
--- bzrlib/tests/per_workingtree/test_basis_inventory.py	2009-08-17 06:58:22 +0000
+++ bzrlib/tests/per_workingtree/test_basis_inventory.py	2011-05-04 20:44:14 +0000
@@ -14,13 +14,8 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-import os
-
 from bzrlib.tests import TestNotApplicable
 from bzrlib.tests.per_workingtree import TestCaseWithWorkingTree
-from bzrlib.branch import Branch
-from bzrlib import inventory
-from bzrlib.revision import Revision
 import bzrlib.xml6
 
 

=== modified file 'bzrlib/tests/per_workingtree/test_check.py'
--- bzrlib/tests/per_workingtree/test_check.py	2009-08-04 04:47:35 +0000
+++ bzrlib/tests/per_workingtree/test_check.py	2011-04-21 20:32:16 +0000
@@ -16,9 +16,6 @@
 
 """Tests for checking of trees."""
 
-from bzrlib import (
-    tests,
-    )
 from bzrlib.tests.per_workingtree import TestCaseWithWorkingTree
 
 

=== modified file 'bzrlib/tests/per_workingtree/test_executable.py'
--- bzrlib/tests/per_workingtree/test_executable.py	2011-04-14 07:53:38 +0000
+++ bzrlib/tests/per_workingtree/test_executable.py	2011-05-04 20:44:14 +0000
@@ -21,7 +21,6 @@
 from bzrlib import (
     osutils,
     )
-from bzrlib.inventory import InventoryFile
 from bzrlib.transform import TreeTransform
 from bzrlib.tests.per_workingtree import TestCaseWithWorkingTree
 

=== modified file 'bzrlib/tests/per_workingtree/test_flush.py'
--- bzrlib/tests/per_workingtree/test_flush.py	2009-08-25 23:38:10 +0000
+++ bzrlib/tests/per_workingtree/test_flush.py	2011-05-04 20:44:14 +0000
@@ -17,7 +17,7 @@
 """Tests for WorkingTree.flush."""
 
 import sys
-from bzrlib import errors, inventory
+from bzrlib import errors
 from bzrlib.tests import TestSkipped
 from bzrlib.tests.per_workingtree import TestCaseWithWorkingTree
 

=== modified file 'bzrlib/tests/per_workingtree/test_inv.py'
--- bzrlib/tests/per_workingtree/test_inv.py	2011-04-09 19:25:42 +0000
+++ bzrlib/tests/per_workingtree/test_inv.py	2011-04-21 20:32:16 +0000
@@ -29,14 +29,14 @@
         wt = self.make_branch_and_tree('b1')
         wt.lock_tree_write()
         self.addCleanup(wt.unlock)
-        self.assertEqual(len(wt.inventory), 1)
+        self.assertEqual(len(wt.all_file_ids()), 1)
         open('b1/a', 'wb').write('a test\n')
         wt.add('a')
-        self.assertEqual(len(wt.inventory), 2)
+        self.assertEqual(len(wt.all_file_ids()), 2)
         wt.flush() # workaround revert doing wt._write_inventory for now.
         os.unlink('b1/a')
         wt.revert()
-        self.assertEqual(len(wt.inventory), 1)
+        self.assertEqual(len(wt.all_file_ids()), 1)
 
 
 class TestApplyInventoryDelta(TestCaseWithWorkingTree):

=== modified file 'bzrlib/tests/per_workingtree/test_parents.py'
--- bzrlib/tests/per_workingtree/test_parents.py	2009-09-09 01:05:31 +0000
+++ bzrlib/tests/per_workingtree/test_parents.py	2011-05-04 20:44:14 +0000
@@ -16,14 +16,12 @@
 
 """Tests of the parent related functions of WorkingTrees."""
 
-from errno import EEXIST
 import os
 
 from bzrlib import (
     errors,
     osutils,
     revision as _mod_revision,
-    symbol_versioning,
     tests,
     )
 from bzrlib.inventory import (

=== modified file 'bzrlib/tests/per_workingtree/test_read_working_inventory.py'
--- bzrlib/tests/per_workingtree/test_read_working_inventory.py	2009-07-10 07:14:02 +0000
+++ bzrlib/tests/per_workingtree/test_read_working_inventory.py	2011-04-21 20:32:16 +0000
@@ -17,19 +17,27 @@
 """Tests for WorkingTree.read_working_inventory."""
 
 from bzrlib import errors, inventory
+from bzrlib.tests import TestNotApplicable
 from bzrlib.tests.per_workingtree import TestCaseWithWorkingTree
+from bzrlib.workingtree import InventoryWorkingTree
 
 
 class TestReadWorkingInventory(TestCaseWithWorkingTree):
 
     def test_trivial_read(self):
         tree = self.make_branch_and_tree('t1')
+        if not isinstance(tree, InventoryWorkingTree):
+            raise TestNotApplicable("read_working_inventory not usable on "
+                "non-inventory working trees")
         tree.lock_read()
         self.assertIsInstance(tree.read_working_inventory(), inventory.Inventory)
         tree.unlock()
 
     def test_read_after_inventory_modification(self):
         tree = self.make_branch_and_tree('tree')
+        if not isinstance(tree, InventoryWorkingTree):
+            raise TestNotApplicable("read_working_inventory not usable on "
+                "non-inventory working trees")
         # prepare for a series of changes that will modify the
         # inventory
         tree.lock_write()

=== modified file 'bzrlib/tests/per_workingtree/test_rename_one.py'
--- bzrlib/tests/per_workingtree/test_rename_one.py	2011-04-15 07:01:22 +0000
+++ bzrlib/tests/per_workingtree/test_rename_one.py	2011-04-21 20:32:16 +0000
@@ -221,7 +221,7 @@
                               tree.basis_tree())
 
     def test_rename_one_after_source_removed(self):
-        """Rename even if the source was removed from the inventory already"""
+        """Rename even if the source was already unversioned."""
         tree = self.make_branch_and_tree('.')
         self.build_tree(['a', 'b/'])
         tree.add(['a', 'b'], ['a-id', 'b-id'])

=== modified file 'bzrlib/tests/per_workingtree/test_set_root_id.py'
--- bzrlib/tests/per_workingtree/test_set_root_id.py	2010-01-13 23:06:42 +0000
+++ bzrlib/tests/per_workingtree/test_set_root_id.py	2011-05-04 20:44:14 +0000
@@ -18,7 +18,7 @@
 
 import sys
 
-from bzrlib import errors, inventory
+from bzrlib import errors
 from bzrlib.tests import TestSkipped
 from bzrlib.tests.per_workingtree import TestCaseWithWorkingTree
 

=== modified file 'bzrlib/tests/per_workingtree/test_smart_add.py'
--- bzrlib/tests/per_workingtree/test_smart_add.py	2011-02-24 16:45:27 +0000
+++ bzrlib/tests/per_workingtree/test_smart_add.py	2011-04-21 20:32:16 +0000
@@ -252,10 +252,10 @@
         self.addCleanup(wt.unlock)
         self.assertEqual([('', wt.path2id('')),
                           ('dir1', 'directory-dir1'),
+                          ('file1', 'file-file1'),
                           ('dir1/file2', 'file-dir1%file2'),
-                          ('file1', 'file-file1'),
                          ], [(path, ie.file_id) for path, ie
-                                in wt.inventory.iter_entries()])
+                                in wt.iter_entries_by_dir()])
 
 
 class TestSmartAddConflictRelatedFiles(per_workingtree.TestCaseWithWorkingTree):
@@ -311,7 +311,7 @@
         self.addCleanup(self.wt.unlock)
         self.assertEqual([('', 'directory'), (u'\xe5', 'file')],
                          [(path, ie.kind) for path,ie in
-                          self.wt.inventory.iter_entries()])
+                          self.wt.iter_entries_by_dir()])
 
     def test_accessible_implicit(self):
         osutils.normalized_filename = osutils._accessible_normalized_filename
@@ -326,7 +326,7 @@
         self.addCleanup(self.wt.unlock)
         self.assertEqual([('', 'directory'), (u'\xe5', 'file')],
                          [(path, ie.kind) for path,ie
-                          in self.wt.inventory.iter_entries()])
+                          in self.wt.iter_entries_by_dir()])
 
     def test_inaccessible_explicit(self):
         osutils.normalized_filename = osutils._inaccessible_normalized_filename

=== modified file 'bzrlib/tests/per_workingtree/test_workingtree.py'
--- bzrlib/tests/per_workingtree/test_workingtree.py	2011-04-20 16:40:53 +0000
+++ bzrlib/tests/per_workingtree/test_workingtree.py	2011-04-21 20:32:16 +0000
@@ -41,6 +41,7 @@
     TreeDirectory,
     TreeFile,
     TreeLink,
+    InventoryWorkingTree,
     WorkingTree,
     )
 from bzrlib.conflicts import ConflictList, TextConflict, ContentsConflict
@@ -244,21 +245,19 @@
         revid = b.revision_history()[0]
         self.log('first revision_id is {%s}' % revid)
 
-        inv = b.repository.get_inventory(revid)
-        self.log('contents of inventory: %r' % inv.entries())
+        tree = b.repository.revision_tree(revid)
+        self.log('contents of tree: %r' % list(tree.iter_entries_by_dir()))
 
-        self.check_inventory_shape(inv,
-                                   ['dir/', 'dir/sub/', 'dir/sub/file'])
+        self.check_tree_shape(tree, ['dir/', 'dir/sub/', 'dir/sub/file'])
         wt.rename_one('dir', 'newdir')
 
         wt.lock_read()
-        self.check_inventory_shape(wt.inventory,
+        self.check_tree_shape(wt,
                                    ['newdir/', 'newdir/sub/', 'newdir/sub/file'])
         wt.unlock()
         wt.rename_one('newdir/sub', 'newdir/newsub')
         wt.lock_read()
-        self.check_inventory_shape(wt.inventory,
-                                   ['newdir/', 'newdir/newsub/',
+        self.check_tree_shape(wt, ['newdir/', 'newdir/newsub/',
                                     'newdir/newsub/file'])
         wt.unlock()
 
@@ -775,7 +774,7 @@
             tree.lock_read()
             self.assertEqual([('', 'directory'), (u'\xe5', 'file')],
                     [(path, ie.kind) for path,ie in
-                                tree.inventory.iter_entries()])
+                                tree.iter_entries_by_dir()])
             tree.unlock()
         finally:
             osutils.normalized_filename = orig
@@ -797,6 +796,9 @@
     def test__write_inventory(self):
         # The private interface _write_inventory is currently used by transform.
         tree = self.make_branch_and_tree('.')
+        if not isinstance(tree, InventoryWorkingTree):
+            raise TestNotApplicable("_write_inventory does not exist on "
+                "non-inventory working trees")
         # if we write write an inventory then do a walkdirs we should get back
         # missing entries, and actual, and unknowns as appropriate.
         self.build_tree(['present', 'unknown'])

=== modified file 'bzrlib/tests/test_bzrdir.py'
--- bzrlib/tests/test_bzrdir.py	2011-04-15 07:01:22 +0000
+++ bzrlib/tests/test_bzrdir.py	2011-05-04 22:23:20 +0000
@@ -38,7 +38,7 @@
     transport as _mod_transport,
     urlutils,
     win32utils,
-    workingtree,
+    workingtree_3,
     )
 import bzrlib.branch
 from bzrlib.errors import (
@@ -807,7 +807,7 @@
         branch = self.make_branch('branch', format='knit')
         format = branch.bzrdir.cloning_metadir()
         self.assertIsInstance(format.workingtree_format,
-            workingtree.WorkingTreeFormat3)
+            workingtree_3.WorkingTreeFormat3)
 
     def test_sprout_recursive_treeless(self):
         tree = self.make_branch_and_tree('tree1',
@@ -963,7 +963,7 @@
         checkout_base = t.clone('checkout').base
         self.assertEqual(checkout_base, dir.get_workingtree_transport(None).base)
         self.assertEqual(checkout_base,
-                         dir.get_workingtree_transport(workingtree.WorkingTreeFormat3()).base)
+                         dir.get_workingtree_transport(workingtree_3.WorkingTreeFormat3()).base)
 
     def test_meta1dir_uses_lockdir(self):
         """Meta1 format uses a LockDir to guard the whole directory, not a file."""
@@ -1057,7 +1057,7 @@
         my_bzrdir = bzrdir.BzrDir.open(self.get_url('branch-knit2'))
         checkout_format = my_bzrdir.checkout_metadir()
         self.assertIsInstance(checkout_format.workingtree_format,
-                              workingtree.WorkingTreeFormat3)
+                              workingtree_3.WorkingTreeFormat3)
 
 
 class TestHTTPRedirections(object):

=== modified file 'bzrlib/tests/test_commit.py'
--- bzrlib/tests/test_commit.py	2011-04-16 08:42:21 +0000
+++ bzrlib/tests/test_commit.py	2011-04-20 16:26:15 +0000
@@ -262,18 +262,16 @@
         eq(tree1.id2path('hello-id'), 'hello')
         eq(tree1.get_file_text('hello-id'), 'contents of hello\n')
         self.assertFalse(tree1.has_filename('fruity'))
-        self.check_inventory_shape(tree1.inventory, ['hello'])
-        ie = tree1.inventory['hello-id']
-        eq(ie.revision, 'test@rev-1')
+        self.check_tree_shape(tree1, ['hello'])
+        eq(tree1.get_file_revision('hello-id'), 'test@rev-1')
 
         tree2 = b.repository.revision_tree('test@rev-2')
         tree2.lock_read()
         self.addCleanup(tree2.unlock)
         eq(tree2.id2path('hello-id'), 'fruity')
         eq(tree2.get_file_text('hello-id'), 'contents of hello\n')
-        self.check_inventory_shape(tree2.inventory, ['fruity'])
-        ie = tree2.inventory['hello-id']
-        eq(ie.revision, 'test@rev-2')
+        self.check_tree_shape(tree2, ['fruity'])
+        eq(tree2.get_file_revision('hello-id'), 'test@rev-2')
 
     def test_reused_rev_id(self):
         """Test that a revision id cannot be reused in a branch"""
@@ -300,8 +298,7 @@
         wt.commit('two', rev_id=r2, allow_pointless=False)
         wt.lock_read()
         try:
-            self.check_inventory_shape(wt.read_working_inventory(),
-                                       ['a/', 'a/hello', 'b/'])
+            self.check_tree_shape(wt, ['a/', 'a/hello', 'b/'])
         finally:
             wt.unlock()
 
@@ -310,9 +307,9 @@
         wt.commit('three', rev_id=r3, allow_pointless=False)
         wt.lock_read()
         try:
-            self.check_inventory_shape(wt.read_working_inventory(),
+            self.check_tree_shape(wt,
                                        ['a/', 'a/hello', 'a/b/'])
-            self.check_inventory_shape(b.repository.get_inventory(r3),
+            self.check_tree_shape(b.repository.revision_tree(r3),
                                        ['a/', 'a/hello', 'a/b/'])
         finally:
             wt.unlock()
@@ -322,8 +319,7 @@
         wt.commit('four', rev_id=r4, allow_pointless=False)
         wt.lock_read()
         try:
-            self.check_inventory_shape(wt.read_working_inventory(),
-                                       ['a/', 'a/b/hello', 'a/b/'])
+            self.check_tree_shape(wt, ['a/', 'a/b/hello', 'a/b/'])
         finally:
             wt.unlock()
 

=== modified file 'bzrlib/tests/test_selftest.py'
--- bzrlib/tests/test_selftest.py	2011-05-04 01:42:10 +0000
+++ bzrlib/tests/test_selftest.py	2011-05-04 22:23:20 +0000
@@ -52,6 +52,7 @@
     tests,
     transport,
     workingtree,
+    workingtree_3,
     workingtree_4,
     )
 from bzrlib.repofmt import (
@@ -340,7 +341,7 @@
         server1 = "a"
         server2 = "b"
         formats = [workingtree_4.WorkingTreeFormat4(),
-                   workingtree.WorkingTreeFormat3(),]
+                   workingtree_3.WorkingTreeFormat3(),]
         scenarios = make_scenarios(server1, server2, formats)
         self.assertEqual([
             ('WorkingTreeFormat4',
@@ -377,7 +378,7 @@
         server1 = "a"
         server2 = "b"
         formats = [workingtree_4.WorkingTreeFormat4(),
-                   workingtree.WorkingTreeFormat3(),]
+                   workingtree_3.WorkingTreeFormat3(),]
         scenarios = make_scenarios(server1, server2, formats)
         self.assertEqual(7, len(scenarios))
         default_wt_format = workingtree.format_registry.get_default()
@@ -2812,16 +2813,16 @@
         self.assertEqual(remaining_names, _test_ids(split_suite[1]))
 
 
-class TestCheckInventoryShape(tests.TestCaseWithTransport):
+class TestCheckTreeShape(tests.TestCaseWithTransport):
 
-    def test_check_inventory_shape(self):
+    def test_check_tree_shape(self):
         files = ['a', 'b/', 'b/c']
         tree = self.make_branch_and_tree('.')
         self.build_tree(files)
         tree.add(files)
         tree.lock_read()
         try:
-            self.check_inventory_shape(tree.inventory, files)
+            self.check_tree_shape(tree, files)
         finally:
             tree.unlock()
 

=== modified file 'bzrlib/tests/test_workingtree.py'
--- bzrlib/tests/test_workingtree.py	2011-05-04 14:54:13 +0000
+++ bzrlib/tests/test_workingtree.py	2011-05-04 22:23:20 +0000
@@ -84,7 +84,7 @@
         format = SampleTreeFormat()
         workingtree.format_registry.register(format)
         self.addCleanup(workingtree.format_registry.remove, format)
-        self.assertTrue(isinstance(old_format, workingtree.WorkingTreeFormat3))
+        self.assertTrue(isinstance(old_format, workingtree_3.WorkingTreeFormat3))
         workingtree.format_registry.set_default_key(format.get_format_string())
         try:
             # the default branch format is used by the meta dir format

=== modified file 'bzrlib/workingtree.py'
--- bzrlib/workingtree.py	2011-05-04 14:54:13 +0000
+++ bzrlib/workingtree.py	2011-05-04 22:23:20 +0000
@@ -750,36 +750,6 @@
         self._set_merges_from_parent_ids(revision_ids)
 
     @needs_tree_write_lock
-    def set_parent_trees(self, parents_list, allow_leftmost_as_ghost=False):
-        """See MutableTree.set_parent_trees."""
-        parent_ids = [rev for (rev, tree) in parents_list]
-        for revision_id in parent_ids:
-            _mod_revision.check_not_reserved_id(revision_id)
-
-        self._check_parents_for_ghosts(parent_ids,
-            allow_leftmost_as_ghost=allow_leftmost_as_ghost)
-
-        parent_ids = self._filter_parent_ids_by_ancestry(parent_ids)
-
-        if len(parent_ids) == 0:
-            leftmost_parent_id = _mod_revision.NULL_REVISION
-            leftmost_parent_tree = None
-        else:
-            leftmost_parent_id, leftmost_parent_tree = parents_list[0]
-
-        if self._change_last_revision(leftmost_parent_id):
-            if leftmost_parent_tree is None:
-                # If we don't have a tree, fall back to reading the
-                # parent tree from the repository.
-                self._cache_basis_inventory(leftmost_parent_id)
-            else:
-                inv = leftmost_parent_tree.inventory
-                xml = self._create_basis_xml_from_inventory(
-                                        leftmost_parent_id, inv)
-                self._write_basis_inventory(xml)
-        self._set_merges_from_parent_ids(parent_ids)
-
-    @needs_tree_write_lock
     def set_pending_merges(self, rev_list):
         parents = self.get_parent_ids()
         leftmost = parents[:1]
@@ -1977,6 +1947,36 @@
         """See Tree.iter_all_file_ids"""
         return set(self.inventory)
 
+    @needs_tree_write_lock
+    def set_parent_trees(self, parents_list, allow_leftmost_as_ghost=False):
+        """See MutableTree.set_parent_trees."""
+        parent_ids = [rev for (rev, tree) in parents_list]
+        for revision_id in parent_ids:
+            _mod_revision.check_not_reserved_id(revision_id)
+
+        self._check_parents_for_ghosts(parent_ids,
+            allow_leftmost_as_ghost=allow_leftmost_as_ghost)
+
+        parent_ids = self._filter_parent_ids_by_ancestry(parent_ids)
+
+        if len(parent_ids) == 0:
+            leftmost_parent_id = _mod_revision.NULL_REVISION
+            leftmost_parent_tree = None
+        else:
+            leftmost_parent_id, leftmost_parent_tree = parents_list[0]
+
+        if self._change_last_revision(leftmost_parent_id):
+            if leftmost_parent_tree is None:
+                # If we don't have a tree, fall back to reading the
+                # parent tree from the repository.
+                self._cache_basis_inventory(leftmost_parent_id)
+            else:
+                inv = leftmost_parent_tree.inventory
+                xml = self._create_basis_xml_from_inventory(
+                                        leftmost_parent_id, inv)
+                self._write_basis_inventory(xml)
+        self._set_merges_from_parent_ids(parent_ids)
+
     def _cache_basis_inventory(self, new_revision):
         """Cache new_revision as the basis inventory."""
         # TODO: this should allow the ready-to-use inventory to be passed in,

